@@ -4,12 +4,15 @@
 import board
 from rainbowio import colorwheel
 from adafruit_is31fl3741.adafruit_ledglasses import LED_Glasses
+import adafruit_is31fl3741
 
-glasses = LED_Glasses(board.I2C())
+glasses = LED_Glasses(board.I2C(), allocate=adafruit_is31fl3741.MUST_BUFFER)
 
 wheeloffset = 0
 while True:
     for i in range(24):
-        glasses.right_ring[i] = colorwheel(i / 24 * 255 + wheeloffset)
-        glasses.left_ring[23 - i] = colorwheel(i / 24 * 255 + wheeloffset)
+        hue = colorwheel(i * 256 // 24 + wheeloffset)
+        glasses.right_ring[i] = hue
+        glasses.left_ring[23 - i] = hue
+    glasses.show()
     wheeloffset += 10
